==> batchcomputecli-0.0.10.tar.gz: batchcomputecli-0.0.10/batchcomputecli/cli.py <==
from terminal import Logger, red
from externals.command import Command
from .actions import login, whoami, images, jobs, job, update_job, \
    remove_job, start_job, stop_job, create_job, get_log,\
    create_project,update_project,build_project,submit_job

from . import const


COMMAND = const.COMMAND

VERSION = const.VERSION

DESCRIPTION = 'description'

SPLITER = '\n    %s' % ('-' * 50)

def __main():
    print('\n  type %s -h for more information\n' % COMMAND)

program = Command(COMMAND, description=DESCRIPTION, version=VERSION, func=__main)

# login
cmd_login = Command('login', description='login with Aliyun AccessKey', func=login.login,
                    arguments=['region', 'accessKeyId', 'accessKeySecret'],
                    usage='''Usage: %s login <region|endpoint> <accessKeyId> <accessKeySecret>''' % (COMMAND))
program.action(cmd_login)

# whoami
cmd_whoami = Command('who', alias=['me','whoami'],description='get login info%s' % SPLITER, func=whoami.get)
program.action(cmd_whoami)


# images
cmd_images = Command('images', alias=['img'],description='list images', func=images.list)
cmd_images.option('-p, --platform [platform]', 'filter by platform, scope:[All|Linux|Window],default:All',
                  resolve=images.transform_platform)
program.action(cmd_images)


# jobs
cmd_jobs = Command('jobs', description='list jobs', func=jobs.list)
cmd_jobs.option('-a, --all', 'show all fields')
cmd_jobs.option('-s, --state [state]',
                'filter by State, scope:[All|Ready|Running|Failed|Finished|Stopped], default:All',
                resolve=jobs.transform_state)
cmd_jobs.option('-o, --order_by [field_name]', 'order by a field')
cmd_jobs.option('-d, --desc [true|false]', 'reverse result array, default: true')
cmd_jobs.option('-l, --limit [number]', 'limit the length of the result')
# cmd_jobs.option('-w, --watch', 'in watch mode, auto refresh every 3 seconds')
program.action(cmd_jobs)

# job
cmd_job = Command('job', description='get job detail, task detail, instance logs',
                  arguments=['job_id', 'task_name', 'instance_id'],
                  usage="""Usage: %s job <job_id> [task_name] [instance_id] [option]

      1. show job detail: %s job <job_id>
      2. show task detail: %s job <job_id> [task_name]
      3. list instance logs: %s job <job_id> [task_name] [instance_id]""" % (COMMAND, COMMAND, COMMAND, COMMAND),
                  func=job.getDetail)
# cmd_job.option('-w, --watch', 'in watch mode, auto refresh every 3 seconds')
program.action(cmd_job)



# get_log
cmd_get_log = Command('get_log', alias=['log'], description='get instance log from oss_path%s' % SPLITER,
                      arguments=['oss_path'],
                      usage="""Usage: %s get_log <oss_path> [option]

      1. print log: %s get_log oss://mybucket/abc/stdout.0.1443505842
      2. download:  %s get_log oss://mybucket/abc/stdout.0.1443505842 -f ./
                      """ %(COMMAND, COMMAND, COMMAND),
                      func=get_log.get_log)
cmd_get_log.option('-f, --file [directory or file]', 'download log to local: -f ./')
program.action(cmd_get_log)



# update_job
cmd_update_job = Command('update_job', alias=['upj'], description='update job properties, currently support "Priority" only',
                         arguments=['job_id'],
                         usage="Usage: %s update_job <job_id> [option]" % (COMMAND),
                         func=update_job.update_priority)
cmd_update_job.option('-p, --priority [n]', 'update job set priority, scope:[0,1000]',
                      resolve=update_job.transform_priority)
program.action(cmd_update_job)



# remove_job
cmd_remove_job = Command('remove_job', alias=['rmj'],description='remove a job',
                         arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=remove_job.remove)
program.action(cmd_remove_job)


# start_job
cmd_start_job = Command('start_job', alias=['start'],description='start a job',
                        arguments=['job_id'],
                        # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                        func=start_job.start)
program.action(cmd_start_job)


# stop_job
cmd_stop_job = Command('stop_job',alias=['stop'], description='stop a job',
                       arguments=['job_id'],
                       # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                       func=stop_job.stop)
program.action(cmd_stop_job)


# submit_job
cmd_create_job = Command('create_job',alias=['cj'], description='create job, from a json string or file%s'%SPLITER,
                         # arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=create_job.create)

cmd_create_job.option('-j, --json [json_string]', 'create a job from a json string: -j "{\\"JobName\\":\"myJob...."',
                      resolve=create_job.transform_json)
cmd_create_job.option('-f, --file [file_path]', 'create a job from json file: -f ./myjob.json',
                      resolve=create_job.transform_file)
program.action(cmd_create_job)


#########################################

# create_project
cmd_create_project = Command('create_project', alias=['cp'], description='create job project',
                        arguments=['project_name','location'],
                        usage="""Usage: %s create_project <project_name> [location] [option]

    1. example1: %s create_project my_project
    2. example2: %s create_project my_project ./ -t java """ % (COMMAND,COMMAND,COMMAND),
                        func=create_project.create)
cmd_create_project.option('-t, --type [type]', 'project type, scope:[python|java|native],default:python',
                      resolve=create_project.transform_type)
program.action(cmd_create_project)



# update_project
cmd_update_project = Command('update_project', alias=['upp'], description='set oss path, set image id',
                        arguments=['project_name','location'],
                        usage="""Usage: %s update_project [option]

    1. update oss_path: %s update_project -o oss://my-bucket/my-key/
    2. update image id: %s update_project -i img-0000000055B9E83C00003ADC00000068 """ % (COMMAND,COMMAND,COMMAND),
                        func=update_project.update)
cmd_update_project.option('-o, --oss_path [oss_path]', 'set the oss path, and it will be synchronized to PackageUri,StdoutRedirectPath & StderrRedirectPath',
                      resolve=update_project.transform_oss_path)
cmd_update_project.option('-i, --image_id [image_id]', 'use image_id, type "%s images -h" for more information' % COMMAND,
                      resolve=update_project.transform_image_id)
program.action(cmd_update_project)



# build_project
cmd_build_project = Command('build_project', alias=['build'], description='make worker.tar.gz',
                        usage="""Usage: %s build_project [option]""" % (COMMAND),
                        func=build_project.build)
program.action(cmd_build_project)


# create_project
cmd_submit_job = Command('submit_job', alias=['submit'],description='upload worker.tar.gz and submit the job',
                        arguments=['oss_path'],
                        usage="""Usage: %s submit_job [option]""" % (COMMAND),
                        func=submit_job.submit)
program.action(cmd_submit_job)

def main():
    try:
        program.parse()
    except Exception, e:
        print(red(e.message or e))

==> batchcomputecli-0.0.11.tar.gz: batchcomputecli-0.0.11/batchcomputecli/cli.py <==
from terminal import Logger, red
from externals.command import Command
from .actions import login, whoami, images, jobs, job, update_job, \
    remove_job, start_job, stop_job, create_job, get_log,\
    create_project,update_project,build_project,submit_job

from . import const


COMMAND = const.COMMAND

VERSION = const.VERSION

DESCRIPTION = 'description'

SPLITER = '\n    %s' % ('-' * 50)

def __main():
    program.print_help()

program = Command(COMMAND, description=DESCRIPTION, version=VERSION, func=__main)



# login
cmd_login = Command('login', description='login with Aliyun AccessKey', func=login.login,
                    arguments=['region', 'accessKeyId', 'accessKeySecret'],
                    usage='''Usage: %s login <region|endpoint> <accessKeyId> <accessKeySecret>''' % (COMMAND))
program.action(cmd_login)

# whoami
cmd_whoami = Command('me',alias=['who','whoami'],description='get login info%s' % SPLITER, func=whoami.get)
program.action(cmd_whoami)


# images
cmd_images = Command('images', alias=['imgs','img'],description='list images', func=images.list)
cmd_images.option('-p, --platform [platform]', 'filter by platform, scope:[All|Linux|Window],default:All',
                  resolve=images.transform_platform)
program.action(cmd_images)


# jobs
cmd_jobs = Command('jobs', description='list jobs', func=jobs.list)
cmd_jobs.option('-a, --all', 'show all fields')
cmd_jobs.option('-s, --state [state]',
                'filter by State, scope:[All|Waiting|Running|Failed|Finished|Stopped], default:All',
                resolve=jobs.transform_state)
cmd_jobs.option('-o, --order_by [field_name]', 'order by a field')
cmd_jobs.option('-d, --desc [true|false]', 'reverse result array, default: true')
cmd_jobs.option('-l, --limit [number]', 'limit the length of the result',
                resolve=jobs.transform_limit)
# cmd_jobs.option('-w, --watch', 'in watch mode, auto refresh every 3 seconds')
program.action(cmd_jobs)

# job
cmd_job = Command('job', description='get job detail, task detail, instance logs',
                  arguments=['job_id', 'task_name', 'instance_id'],
                  usage="""Usage: %s job <job_id> [task_name] [instance_id] [option]

      1. show job detail: %s job <job_id>
      2. show task detail: %s job <job_id> <task_name>
      3. list instance logs: %s job <job_id> <task_name> <instance_id> [--limit 10]""" % (COMMAND, COMMAND, COMMAND, COMMAND),
                  func=job.getDetail)
cmd_job.option('-l, --limit [number]', 'limit the length of the result, only works in list instance logs')
program.action(cmd_job)



# get_log
cmd_get_log = Command('get_log', alias=['log'], description='get instance log from oss_path%s' % SPLITER,
                      arguments=['oss_path'],
                      usage="""Usage: %s get_log <oss_path> [option]

      1. print log: %s get_log oss://mybucket/abc/stdout.0.1443505842
      2. download:  %s get_log oss://mybucket/abc/stdout.0.1443505842 -f ./
                      """ %(COMMAND, COMMAND, COMMAND),
                      func=get_log.get_log)
cmd_get_log.option('-f, --file [directory or file]', 'download log to local: -f ./')
program.action(cmd_get_log)



# update_job
cmd_update_job = Command('update_job', alias=['update'], description='update job properties, currently support "Priority" only',
                         arguments=['job_id'],
                         usage="Usage: %s update_job <job_id> [option]" % (COMMAND),
                         func=update_job.update_priority)
cmd_update_job.option('-p, --priority [n]', 'update job set priority, scope:[0,1000]',
                      resolve=update_job.transform_priority)
program.action(cmd_update_job)



# remove_job
cmd_remove_job = Command('remove_job', alias=['rm','remove'],description='remove a job',
                         arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=remove_job.remove)
program.action(cmd_remove_job)


# start_job
cmd_start_job = Command('start_job', alias=['start'],description='start a job',
                        arguments=['job_id'],
                        # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                        func=start_job.start)
program.action(cmd_start_job)


# stop_job
cmd_stop_job = Command('stop_job',alias=['stop'], description='stop a job',
                       arguments=['job_id'],
                       # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                       func=stop_job.stop)
program.action(cmd_stop_job)


# submit_job
cmd_create_job = Command('create_job',alias=['create'], description='create job, from a json string or file%s'%SPLITER,
                         # arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=create_job.create)

cmd_create_job.option('-j, --json [json_string]', 'create a job from a json string: -j "{\\"JobName\\":\"myJob...."',
                      resolve=create_job.transform_json)
cmd_create_job.option('-f, --file [file_path]', 'create a job from json file: -f ./myjob.json',
                      resolve=create_job.transform_file)
program.action(cmd_create_job)


#########################################

# create_project
cmd_create_project = Command('create_project', description='create job project',
                        arguments=['project_name','location'],
                        usage="""Usage: %s create_project <project_name> [location] [option]

    1. example1: %s create_project my_project
    2. example2: %s create_project my_project ./ -t java """ % (COMMAND,COMMAND,COMMAND),
                        func=create_project.create)
cmd_create_project.option('-t, --type [type]', 'project type, scope:[python|java|native],default:python',
                      resolve=create_project.transform_type)
program.action(cmd_create_project)



# update_project
cmd_update_project = Command('update_project', description='set oss path, set image id',
                        arguments=['project_name','location'],
                        usage="""Usage: %s update_project [option]

    1. update oss_path: %s update_project -o oss://my-bucket/my-key/
    2. update image id: %s update_project -i img-0000000055B9E83C00003ADC00000068 """ % (COMMAND,COMMAND,COMMAND),
                        func=update_project.update)
cmd_update_project.option('-o, --oss_path [oss_path]', 'set the oss path, and it will be synchronized to PackageUri,StdoutRedirectPath & StderrRedirectPath',
                      resolve=update_project.transform_oss_path)
cmd_update_project.option('-i, --image_id [image_id]', 'use image_id, type "%s images -h" for more information' % COMMAND,
                      resolve=update_project.transform_image_id)
program.action(cmd_update_project)



# build_project
cmd_build_project = Command('build_project', alias=['build'], description='make worker.tar.gz',
                        usage="""Usage: %s build_project [option]""" % (COMMAND),
                        func=build_project.build)
program.action(cmd_build_project)


# create_project
cmd_submit_job = Command('submit_job', alias=['submit'],description='upload worker.tar.gz and create a job',
                        arguments=['oss_path'],
                        usage="""Usage: %s submit_job [option]""" % (COMMAND),
                        func=submit_job.submit)
program.action(cmd_submit_job)

def main():
    try:
        program.parse()
    except Exception, e:
        print('\n  %s\n' % red(e.message or e))
